@@ -154,9 +154,6 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 	
 		m_chmFile = new_chmfile;
 
-//		delete m_viewWindowMgr;
-		//m_viewWindowMgr = new KCHMViewWindowMgr( m_windowSplitter );
-		
 		QDir qd;
 		qd.setPath (fileName);
 		m_chmFilename = qd.absPath();
@@ -216,6 +213,14 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 				m_viewWindowMgr->restoreSettings( m_currentSettings->m_viewwindows );
 				m_viewWindowMgr->setCurrentPage( m_currentSettings->m_activetabwindow );
 			}
+			
+			// Restore the main window size
+			QValueList<int> sizes;
+			sizes.push_back( m_currentSettings->m_window_size_splitter );
+			sizes.push_back( m_currentSettings->m_window_size_x - m_currentSettings->m_window_size_splitter );
+			
+			m_windowSplitter->setSizes( sizes );
+			resize( m_currentSettings->m_window_size_x, m_currentSettings->m_window_size_y );
 		}
 		else
 		{
@@ -318,6 +323,9 @@ void KCHMMainWindow::slotOnTreeClicked( QListViewItem * item )
 
 void KCHMMainWindow::slotLinkClicked ( const QString & link, bool& follow_link )
 {
+	if ( link.isEmpty() )
+		return;
+	
 	if ( gKeyEventFilter.isShiftPressed() )
 	{
 		openPage( link, OPF_NEW_TAB | OPF_CONTENT_TREE );
@@ -556,7 +564,11 @@ void KCHMMainWindow::closeChmFile( )
 		m_currentSettings->m_activeencodinglcid = m_chmFile->getCurrentEncoding()->winlcid;
 		m_currentSettings->m_activetabsystem = m_tabWidget->currentPageIndex( );
 		m_currentSettings->m_activetabwindow = m_viewWindowMgr->currentPageIndex( );
-			
+		
+		m_currentSettings->m_window_size_x = width();
+		m_currentSettings->m_window_size_y = height();
+		m_currentSettings->m_window_size_splitter = m_windowSplitter->sizes()[0];
+		
 		if ( m_searchWindow )
 			m_searchWindow->saveSettings (m_currentSettings->m_searchhistory);
 				
@@ -728,17 +740,51 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 
 		appConfig.m_QtBrowserPath = dlg.m_qtBrowserPath->text();
 		
-		appConfig.m_kdeEnableJS = dlg.m_enableJS->isChecked();
-		appConfig.m_kdeEnablePlugins = dlg.m_enablePlugins->isChecked();
-		appConfig.m_kdeEnableJava = dlg.m_enableJava->isChecked();
-		appConfig.m_kdeEnableRefresh = dlg.m_enableRefresh->isChecked();
-		appConfig.m_kdeUseQTextBrowser = dlg.m_radioUseQtextBrowser->isChecked();
+		// Check the changes
+		bool need_restart = false;
+		
+		if ( appConfig.m_kdeEnableJS != dlg.m_enableJS->isChecked() )
+		{
+			need_restart = true;
+			appConfig.m_kdeEnableJS = dlg.m_enableJS->isChecked();
+		}
+		
+		if ( appConfig.m_kdeEnablePlugins != dlg.m_enablePlugins->isChecked() )
+		{
+			need_restart = true;
+			appConfig.m_kdeEnablePlugins = dlg.m_enablePlugins->isChecked();
+		}
+		
+		if ( appConfig.m_kdeEnableJava != dlg.m_enableJava->isChecked() )
+		{
+			need_restart = true;
+			appConfig.m_kdeEnableJava = dlg.m_enableJava->isChecked();
+		}
+		
+		if ( appConfig.m_kdeEnableRefresh != dlg.m_enableRefresh->isChecked() )
+		{
+			need_restart = true;
+			appConfig.m_kdeEnableRefresh = dlg.m_enableRefresh->isChecked();
+		}
+		
+		if ( appConfig.m_kdeUseQTextBrowser != dlg.m_radioUseQtextBrowser->isChecked() )
+		{
+			need_restart = true;
+			appConfig.m_kdeUseQTextBrowser = dlg.m_radioUseQtextBrowser->isChecked();
+		}
 		
 		appConfig.m_advExternalEditorPath = dlg.m_advExternalProgramName->text();
 		appConfig.m_advUseInternalEditor = dlg.m_advViewSourceExternal->isChecked();
 		appConfig.m_advUseInternalEditor = dlg.m_advViewSourceInternal->isChecked();
 		
 		appConfig.save();
+		
+		if ( need_restart )
+			QMessageBox::information( 
+					this,
+					APP_NAME,
+					i18n( "Changing browser view options require\nrestarting the application to take effect." )
+									);
 	}
 }
 
@@ -828,6 +874,11 @@ void KCHMMainWindow::showOrHideContextWindow( int tabindex )
 					 this, 
 					 SLOT( slotOnTreeClicked( QListViewItem* ) ) );
 			
+			connect( m_contentsWindow, 
+					 SIGNAL( doubleClicked ( QListViewItem *, const QPoint &, int ) ), 
+					 this, 
+					 SLOT( slotOnTreeDoubleClicked ( QListViewItem *, const QPoint &, int ) ) );
+			
 			m_tabWidget->insertTab (m_contentsWindow, i18n( "Contents" ), tabindex);
 		}
 	}
@@ -1075,6 +1126,16 @@ void KCHMMainWindow::locateInContentTree( const QString & url )
 	}
 }
 
+void KCHMMainWindow::slotOnTreeDoubleClicked( QListViewItem * item, const QPoint &, int )
+{
+	// Open/close only existing item which have children
+	if ( !item || item->childCount() == 0 )
+		return;
+	
+	item->setOpen( !item->isOpen() );
+	item->repaint();
+}
+
 
 #if defined (ENABLE_AUTOTEST_SUPPORT)
 void KCHMMainWindow::runAutoTest()
